==> haskell-dense-linear-algebra-0.1.0.0-389-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-HGW9emYUEt2DLF3F4WTlk0
key:                  dense-linear-algebra-0.1.0.0-HGW9emYUEt2DLF3F4WTlk0
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  79a4688c382e034e797bf2bb052fc97c
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-HGW9emYUEt2DLF3F4WTlk0
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    math-functions-0.3.4.4-FVa3z0DxqghFhUkin99UZQ
    primitive-0.9.1.0-IHF3DoB9Qq2KNGfApZUSXg
    vector-0.13.2.0-CQ8QMV1t4PN5YFZtNXivGS
    vector-algorithms-0.9.1.0-JiRJYCHKfes6Y2FWotPY6l
    vector-binary-instances-0.2.5.2-Cv96XxY9T0RIGShoAkpoJZ
    vector-th-unbox-0.2.2-2zeMe1sTC7d4dMpDaHD8tz

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dense-linear-algebra-0.1.0.0-390-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-FjRBV1ajen359ffSOLClt2
key:                  dense-linear-algebra-0.1.0.0-FjRBV1ajen359ffSOLClt2
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  200de95341fe31ee1c9ad5406fb705d8
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-FjRBV1ajen359ffSOLClt2
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    math-functions-0.3.4.4-4rhQnsx9RzY2BQ4pl4DEmJ
    primitive-0.9.1.0-GChnkqMWBe7B15Z0K3IGlf
    vector-0.13.2.0-B39FQf4cXUZ2GlwNF0TDTd
    vector-algorithms-0.9.1.0-8BCQdkwX580Sni8d1Q8yq
    vector-binary-instances-0.2.5.2-Ck7SUjrQjOqEgDen7yJtSg
    vector-th-unbox-0.2.2-wFruAWbkd09XJkwOwVBkp

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
